@@ -1,7 +1,7 @@
 # Orca
 #
 # Copyright 2004-2009 Sun Microsystems Inc.
-# Copyright 2010 Joanmarie Diggs, Mesar Hameed
+# Copyright 2010-2011 The Orca Team
 #
 # This library is free software; you can redistribute it and/or
 # modify it under the terms of the GNU Lesser General Public
@@ -24,7 +24,7 @@ __id__        = "$Id$"
 __version__   = "$Revision$"
 __date__      = "$Date$"
 __copyright__ = "Copyright (c) 2004-2009 Sun Microsystems Inc." \
-                "Copyright (c) 2010 Joanmarie Diggs, Mesar Hameed."
+                "Copyright (c) 2010-2011 The Orca Team"
 __license__   = "LGPL"
 
 import getopt
@@ -35,12 +35,10 @@ import time
 import unicodedata
 import shutil
 
-# This must happen BEFORE we import gtk (until we start using
-# introspection).
 from gi.repository.Gio import Settings
 a11yAppSettings = Settings('org.gnome.desktop.a11y.applications')      
 
-# We're going to force the name of the app to "orca" so pygtk
+# We're going to force the name of the app to "orca" so we
 # will end up showing us as "orca" to the AT-SPI.  If we don't
 # do this, the name can end up being "-c".  See bug 364452 at
 # http://bugzilla.gnome.org/show_bug.cgi?id=364452 for more
@@ -48,15 +46,14 @@ a11yAppSettings = Settings('org.gnome.desktop.a11y.applications')
 #
 sys.argv[0] = "orca"
 import pyatspi
-import pygtk
-pygtk.require('2.0')
 try:
     # This can fail due to gtk not being available.  We want to
     # be able to recover from that if possible.  The main driver
     # for this is to allow "orca --text-setup" to work even if
     # the desktop is not running.
     #
-    import gtk
+    from gi.repository import Gtk
+    from gi.repository import Gdk
 except:
     pass
 
@@ -99,7 +96,7 @@ class Options:
 
         self.desktopRunning = False
         try:
-            if gtk.gdk.display_get_default():
+            if Gdk.Display.get_default():
                 self.desktopRunning = True
         except:
             pass
@@ -107,7 +104,6 @@ class Options:
         self.canEnable = {'speech':'enableSpeech',
                           'braille':'enableBraille',
                           'braille-monitor':'enableBrailleMonitor',
-                          'magnifier':'enableMagnifier',
                           'main-window':'showMainWindow',
                           'splash-window':'showSplashWindow'}
 
@@ -356,13 +352,13 @@ class Options:
         returns False."""
 
         if self.cannotEnable:
-            valid = "\nspeech, braille, braille-monitor, magnifier, " \
+            valid = "\nspeech, braille, braille-monitor, " \
                     "main-window, splash-window"
             # Translators: This message is displayed when the user
             # tries to enable or disable a feature via an argument,
             # but specified an invalid feature. Valid features are:
-            # speech, braille, braille-monitor, magnifier, main-window,
-            # and splash-window. These items are not localized and are
+            # speech, braille, braille-monitor, main-window, and
+            # splash-window. These items are not localized and are
             # presented in a list after this message.
             #
             msg = _("The following items can be enabled or disabled:")
@@ -448,7 +444,6 @@ class Options:
                         + "speech" + "|" \
                         + "braille" + "|" \
                         + "braille-monitor" + "|" \
-                        + "magnifier" + "|" \
                         + "main-window" + "|" \
                         + "splash-window" + "] ")
 
@@ -462,7 +457,6 @@ class Options:
                         + "speech" + "|" \
                         + "braille" + "|" \
                         + "braille-monitor" + "|" \
-                        + "magnifier" + "|" \
                         + "main-window" + "|" \
                         + "splash-window" + "] ")
 
@@ -1161,12 +1155,12 @@ def _processKeyCaptured(event):
             # If it's not on the keypad, get the name of the unshifted
             # character. (i.e. "1" instead of "!")
             #
-            keymap = gtk.gdk.keymap_get_default()
-            entries = keymap.get_entries_for_keycode(event.hw_code)
-            event.event_string = gtk.gdk.keyval_name(entries[0][0])
+            keymap = Gdk.Keymap.get_default()
+            success, entries = keymap.get_entries_for_keycode(event.hw_code)
+            event.event_string = Gdk.keyval_name(entries[0].keycode)
             if event.event_string.startswith("KP") and \
                event.event_string != "KP_Enter":
-                name = gtk.gdk.keyval_name(entries[1][0])
+                name = Gdk.keyval_name(entries[1].keycode)
                 if name.startswith("KP"):
                     event.event_string = name
 
@@ -1694,9 +1688,9 @@ def helpForOrca(script=None, inputEvent=None, page=""):
     uri = "ghelp:orca"
     if page:
         uri += "?%s" % page
-    gtk.show_uri(gtk.gdk.screen_get_default(),
+    Gtk.show_uri(Gdk.Screen.get_default(),
                  uri,
-                 gtk.get_current_event_time())
+                 Gtk.get_current_event_time())
     return True
 
 def listShortcuts(event):
